@@ -2,8 +2,12 @@
 --
 module Hakyll.Web.Util.Html
     ( stripTags
+    , escapeHtml
     ) where
 
+import Text.Blaze (toHtml)
+import Text.Blaze.Renderer.String (renderHtml)
+
 -- | Strip all HTML tags from a string
 --
 -- Example:
@@ -28,3 +32,16 @@ stripTags :: String -> String
 stripTags []         = []
 stripTags ('<' : xs) = stripTags $ drop 1 $ dropWhile (/= '>') xs
 stripTags (x : xs)   = x : stripTags xs
+
+-- | HTML-escape a string
+--
+-- Example:
+--
+-- > escapeHtml "Me & Dean"
+--
+-- Result:
+--
+-- > "Me &amp; Dean"
+--
+escapeHtml :: String -> String
+escapeHtml = renderHtml . toHtml
